@@ -11,7 +11,7 @@ use base qw(DynaLoader);
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '3.403';
+$VERSION = '3.406';
 
 ######################################################################
 #### Configuration Section
@@ -40,6 +40,7 @@ sub new {
 		pedantic=>0,
 		synthesis=>0,
 		options=>Verilog::Getopt->new(),	# If the user didn't give one, still work!
+		parent => undef,
 		#include_open_nonfatal=>0,
 		@_};
     bless $self, $class;
@@ -118,6 +119,11 @@ sub debug {
     $self->_debug($level);
 }
 
+sub parent {
+    my $self = shift;
+    return $self->{parent};
+}
+
 ######################################################################
 #### Utilities
 
@@ -270,6 +276,11 @@ Returns the line number of the last getline().  Note that the line number
 may change several times between getline(), for example when traversing
 multiple include files.
 
+=item $self->parent()
+
+Returns a reference to the Verilog::Netlist::File which created this
+object, if any.
+
 =item $self->new(I<parameters>)
 
 Creates a new preprocessor.  See the PARAMETERS section for the options
